Learn R Programming

redistmetrics (version 1.0.11)

comp_fh: Calculate Fryer Holden Compactness

Description

Calculate Fryer Holden Compactness

Usage

comp_fh(plans, shp, total_pop, epsg = 3857, ncores = 1)

Value

A numeric vector. Can be shaped into a district-by-plan matrix.

Arguments

plans

A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.

shp

A redist_map object, tibble, or data frame with an sf geometry column.

total_pop

A numeric vector with the population for every observation.

epsg

Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.

ncores

TRUE

References

Fryer R, Holden R. 2011. Measuring the Compactness of Political Districting Plans. Journal of Law and Economics.

Examples

Run this code
data(nh)
data(nh_m)
# For a single plan:
comp_fh(plans = nh$r_2020, shp = nh, total_pop = pop)

# Or many plans:
comp_fh(plans = nh_m[, 3:5], shp = nh, pop)

Run the code above in your browser using DataLab