Learn R Programming

redistmetrics (version 1.0.11)

comp_lw: Calculate Length Width Compactness

Description

Calculate Length Width Compactness

Usage

comp_lw(plans, shp, epsg = 3857, ncores = 1)

Value

A numeric vector. Can be shaped into a district-by-plan matrix.

Arguments

plans

A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.

shp

A redist_map object, tibble, or data frame with an sf geometry column.

epsg

Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.

ncores

Integer number of cores to use. Default is 1.

References

Harris, Curtis C. 1964. “A scientific method of districting”. Behavioral Science 3(9), 219–225.

Examples

Run this code
data(nh)
data(nh_m)
# For a single plan:
comp_lw(plans = nh$r_2020, shp = nh)

# Or many plans:
# \donttest{
# slower, beware!
comp_lw(plans = nh_m[, 3:5], shp = nh)
# }

Run the code above in your browser using DataLab