A numeric vector. Can be shaped into a district-by-plan matrix.
Arguments
plans
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
shp
A redist_map object, tibble, or data frame with an sf geometry column.
use_Rcpp
If TRUE (the default for more than 8 plans), precompute boundaries
shared by each pair of units and use them to quickly compute the compactness score.
perim_path
Path to perimeter tibble saved by prep_perims()
perim_df
Tibble of perimeters from prep_perims()
epsg
Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.
ncores
Integer number of cores to use. Default is 1.
References
Cox, E. 1927. A Method of Assigning Numerical and Percentage Values to the
Degree of Roundness of Sand Grains. Journal of Paleontology, 1(3), 179-183.
Polsby, Daniel D., and Robert D. Popper. 1991. “The Third Criterion:
Compactness as a procedural safeguard against partisan gerrymandering.”
Yale Law & Policy Review 9 (2): 301–353.