Learn R Programming

redistmetrics (version 1.0.11)

comp_reock: Calculate Reock Compactness

Description

Calculate Reock Compactness

Usage

comp_reock(plans, shp, epsg = 3857, ncores = 1)

Value

A numeric vector. Can be shaped into a district-by-plan matrix.

Arguments

plans

A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.

shp

A redist_map object, tibble, or data frame with an sf geometry column.

epsg

Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.

ncores

Integer number of cores to use. Default is 1.

References

Reock, E. 1961. A Note: Measuring Compactness as a Requirement of Legislative Apportionment. Midwest Journal of Political Science, 5(1), 70-74.

Examples

Run this code
data(nh)
data(nh_m)
# For a single plan:
comp_reock(plans = nh$r_2020, shp = nh)

# Or many plans:
comp_reock(plans = nh_m[, 3:5], shp = nh)

Run the code above in your browser using DataLab