Learn R Programming

redistmetrics (version 1.0.11)

comp_schwartz: Calculate Schwartzberg Compactness

Description

Calculate Schwartzberg Compactness

Usage

comp_schwartz(
  plans,
  shp,
  use_Rcpp,
  perim_path,
  perim_df,
  epsg = 3857,
  ncores = 1
)

Value

A numeric vector. Can be shaped into a district-by-plan matrix.

Arguments

plans

A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.

shp

A redist_map object, tibble, or data frame with an sf geometry column.

use_Rcpp

Logical. Use Rcpp?

perim_path

path to perimeter tibble saved by prep_perims()

perim_df

tibble of perimeters from prep_perims()

epsg

Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.

ncores

Integer number of cores to use. Default is 1.

References

Schwartzberg, Joseph E. 1966. Reapportionment, Gerrymanders, and the Notion of Compactness. Minnesota Law Review. 1701.

Examples

Run this code
data(nh)
data(nh_m)
# For a single plan:
comp_schwartz(plans = nh$r_2020, shp = nh)

# Or many plans:
comp_schwartz(plans = nh_m[, 3:5], shp = nh)

Run the code above in your browser using DataLab