Skew is defined as the ratio of the radii of the largest inscribed circle with
the smallest bounding circle. Scores are bounded between 0 and 1, where 1 is
most compact.
Usage
comp_skew(plans, shp, epsg = 3857, ncores = 1)
Value
A numeric vector. Can be shaped into a district-by-plan matrix.
Arguments
plans
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
shp
A redist_map object, tibble, or data frame with an sf geometry column.
epsg
Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.
ncores
Integer number of cores to use. Default is 1.
References
S.N. Schumm. 1963. Sinuosity of alluvial rivers on the Great Plains.
Bulletin of the Geological Society of America, 74. 1089-1100.