Learn R Programming

redistmetrics (version 1.0.11)

comp_x_sym: Calculate X Symmetry Compactness

Description

X symmetry is the overlapping area of a shape and its projection over the x-axis.

Usage

comp_x_sym(plans, shp, epsg = 3857, ncores = 1)

Value

A numeric vector. Can be shaped into a district-by-plan matrix.

Arguments

plans

A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.

shp

A redist_map object, tibble, or data frame with an sf geometry column.

epsg

Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.

ncores

Integer number of cores to use. Default is 1.

References

Aaron Kaufman, Gary King, and Mayya Komisarchik. 2021. How to Measure Legislative District Compactness If You Only Know it When You See It. American Journal of Political Science. 65, 3. Pp. 533-550.

Examples

Run this code
#' data(nh)
data(nh_m)
# For a single plan:
comp_x_sym(plans = nh$r_2020, shp = nh)

# Or many plans:
# \donttest{
# slower, beware!
comp_x_sym(plans = nh_m[, 3:5], shp = nh)
# }

Run the code above in your browser using DataLab