Y symmetry is the overlapping area of a shape and its projection over the
y-axis.
Usage
comp_y_sym(plans, shp, epsg = 3857, ncores = 1)
Value
A numeric vector. Can be shaped into a district-by-plan matrix.
Arguments
plans
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
shp
A redist_map object, tibble, or data frame with an sf geometry column.
epsg
Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.
ncores
Integer number of cores to use. Default is 1.
References
Aaron Kaufman, Gary King, and Mayya Komisarchik. 2021.
How to Measure Legislative District Compactness If You Only Know it When You See It.
American Journal of Political Science. 65, 3. Pp. 533-550.