Learn R Programming

redistmetrics (version 1.0.11)

part_decl: Calculate Declination

Description

Calculate Declination

Usage

part_decl(plans, shp, dvote, rvote, normalize = TRUE, adjust = TRUE)

Value

A numeric vector. Can be shaped into a district-by-plan matrix.

Arguments

plans

A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.

shp

A redist_map object, tibble, or data frame containing other columns.

dvote

Unqouted name of column in shp with total population.

rvote

Unqouted name of column in shp with group population.

normalize

Default is TRUE Translate score to an angle?

adjust

Default is TRUE. Applies a correction to increase cross-size comparison.

References

Gregory S. Warrington. 2018. "Quantifying Gerrymandering Using the Vote Distribution." Election Law Journal: Rules, Politics, and Policy. Pp. 39-57.http://doi.org/10.1089/elj.2017.0447

Examples

Run this code
data(nh)
data(nh_m)
# For a single plan:
part_decl(plans = nh$r_2020, shp = nh, rvote = nrv, dvote = ndv)

# Or many plans:
part_decl(plans = nh_m[, 3:5], shp = nh, rvote = nrv, dvote = ndv)

Run the code above in your browser using DataLab