Learn R Programming

redistmetrics (version 1.0.11)

part_egap: Calculate Efficiency Gap

Description

Calculate Efficiency Gap

Usage

part_egap(plans, shp, dvote, rvote)

Value

A numeric vector. Can be shaped into a district-by-plan matrix.

Arguments

plans

A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.

shp

A redist_map object, tibble, or data frame containing other columns.

dvote

Unqouted name of column in shp with total population.

rvote

Unqouted name of column in shp with group population.

References

Nicholas O. Stephanopoulos. 2015. Partisan Gerrymandering and the Efficiency Gap. The University of Chicago Law Review, 82, Pp. 831-900.

Examples

Run this code
data(nh)
data(nh_m)
# For a single plan:
part_egap(plans = nh$r_2020, shp = nh, rvote = nrv, dvote = ndv)

# Or many plans:
part_egap(plans = nh_m[, 3:5], shp = nh, rvote = nrv, dvote = ndv)

Run the code above in your browser using DataLab