part_resp(plans, shp, dvote, rvote, v = 0.5, bandwidth = 0.01)
Value
A numeric vector. Can be shaped into a district-by-plan matrix.
Arguments
plans
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
shp
A redist_map object, tibble, or data frame containing other columns.
dvote
Unqouted name of column in shp with total population.
rvote
Unqouted name of column in shp with group population.
v
vote share to calculate bias at. Numeric. Default is 0.5.
bandwidth
Defaults to 0.01. A value between 0 and 1 for the step size to estimate the slope.
References
Jonathan N. Katz, Gary King, and Elizabeth Rosenblatt. 2020.
Theoretical Foundations and Empirical Evaluations of Partisan Fairness in District-Based Democracies.
American Political Science Review, 114, 1, Pp. 164-178.