A numeric vector. Can be shaped into a district-by-plan matrix.
Arguments
plans
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
shp
A redist_map object, tibble, or data frame containing other columns.
dvote
Unqouted name of column in shp with total population.
rvote
Unqouted name of column in shp with group population.
tau
A non-negative numeric for calculating Tau Gap. Defaults to 1.
References
Gregory S. Warrington. 2018. "Quantifying Gerrymandering Using the Vote Distribution."
Election Law Journal: Rules, Politics, and Policy. Pp. 39-57.http://doi.org/10.1089/elj.2017.0447