powered by
If x is repeated for each district, it returns a plan level value. Otherwise it returns x.
x
by_plan(x, ndists)
x or plan level subset of x
summary statistic at the district level
numeric. Number of districts. Estimated as the gcd of the unique run length encodings if missing.
by_plan(letters) by_plan(rep(letters, each = 2))
Run the code above in your browser using DataLab