powered by
Calculate Boyce Clark Ratio
comp_bc(plans, shp, epsg = 3857, ncores = 1)
A numeric vector. Can be shaped into a district-by-plan matrix.
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
redist_plans
A redist_map object, tibble, or data frame with an sf geometry column.
redist_map
sf
Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.
Integer number of cores to use. Default is 1.
Boyce, R., & Clark, W. 1964. The Concept of Shape in Geography. Geographical Review, 54(4), 561-572.
data(nh) data(nh_m) # For a single plan: comp_bc(plans = nh$r_2020, shp = nh) # Or many plans: # \donttest{ # slower, beware! comp_bc(plans = nh_m[, 3:5], shp = nh) # }
Run the code above in your browser using DataLab