powered by
Calculate Length Width Compactness
comp_lw(plans, shp, epsg = 3857, ncores = 1)
A numeric vector. Can be shaped into a district-by-plan matrix.
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
redist_plans
A redist_map object, tibble, or data frame with an sf geometry column.
redist_map
sf
Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.
Integer number of cores to use. Default is 1.
Harris, Curtis C. 1964. “A scientific method of districting”. Behavioral Science 3(9), 219–225.
data(nh) data(nh_m) # For a single plan: comp_lw(plans = nh$r_2020, shp = nh) # Or many plans: # \donttest{ # slower, beware! comp_lw(plans = nh_m[, 3:5], shp = nh) # }
Run the code above in your browser using DataLab