powered by
Calculate Schwartzberg Compactness
comp_schwartz( plans, shp, use_Rcpp, perim_path, perim_df, epsg = 3857, ncores = 1 )
A numeric vector. Can be shaped into a district-by-plan matrix.
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
redist_plans
A redist_map object, tibble, or data frame with an sf geometry column.
redist_map
sf
Logical. Use Rcpp?
path to perimeter tibble saved by prep_perims()
prep_perims()
tibble of perimeters from prep_perims()
Numeric EPSG code to use to project the shapefile, if needed. Default is 3857.
Integer number of cores to use. Default is 1.
Schwartzberg, Joseph E. 1966. Reapportionment, Gerrymanders, and the Notion of Compactness. Minnesota Law Review. 1701.
data(nh) data(nh_m) # For a single plan: comp_schwartz(plans = nh$r_2020, shp = nh) # Or many plans: comp_schwartz(plans = nh_m[, 3:5], shp = nh)
Run the code above in your browser using DataLab