A numeric vector. Can be shaped into a district-by-plan matrix.
Arguments
plans
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
shp
A redist_map object, tibble, or data frame containing other columns.
dvote
Unqouted name of column in shp with total population.
rvote
Unqouted name of column in shp with group population.
References
Sanford C. Gordon and Sidak Yntiso. 2024.
Base Rate Neglect and the Diagnosis of Partisan Gerrymanders.
Election Law Journal: Rules, Politics, and Policy. tools:::Rd_expr_doi("10.1089/elj.2023.0005").