powered by
Calculate Efficiency Gap
part_egap(plans, shp, dvote, rvote)
A numeric vector. Can be shaped into a district-by-plan matrix.
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
redist_plans
A redist_map object, tibble, or data frame containing other columns.
redist_map
Unqouted name of column in shp with total population.
shp
Unqouted name of column in shp with group population.
Nicholas O. Stephanopoulos. 2015. Partisan Gerrymandering and the Efficiency Gap. The University of Chicago Law Review, 82, Pp. 831-900.
data(nh) data(nh_m) # For a single plan: part_egap(plans = nh$r_2020, shp = nh, rvote = nrv, dvote = ndv) # Or many plans: part_egap(plans = nh_m[, 3:5], shp = nh, rvote = nrv, dvote = ndv)
Run the code above in your browser using DataLab