A numeric vector. Can be shaped into a district-by-plan matrix.
Arguments
plans
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
shp
A redist_map object, tibble, or data frame containing other columns.
dvote
Unqouted name of column in shp with total population.
rvote
Unqouted name of column in shp with group population.
References
Gregory Herschlag, Han Sung Kang, Justin Luo, Christy Vaughn Graves, Sachet Bangia,
Robert Ravier & Jonathan C. Mattingly (2020) Quantifying Gerrymandering in North Carolina,
Statistics and Public Policy, 7:1, 30-38, DOI: 10.1080/2330443X.2020.1796400