powered by
Counts the total number of sub-administrative splits.
splits_sub_total(plans, shp, sub_admin)
numeric matrix
A redist_plans object or plans_matrix where each row indicates a district assignment and each column is a plan.
redist_plans
A redist_map object, tibble, or data frame containing other columns.
redist_map
Unqouted name of column in shp with numeric identifiers for subsidiary administrative units.
data(nh) data(nh_m) # For a single plan: splits_sub_total(plans = nh$r_2020, shp = nh, sub_admin = county) # Or many plans: splits_sub_total(plans = nh_m[, 3:5], shp = nh, sub_admin = county)
Run the code above in your browser using DataLab